@@ -91,6 +91,9 @@ def main():
 		start_creator_proxy(args)
 	elif operation == "filter":
 		start_filter_proxy(args)
+	elif operation == "proxy":
+		args.tcp_connection = 'true'
+		start_creator_proxy(args)
 	else:
 		start_creator_proxy(args)
 
